==> openshift-model-console-6.5.1-sources.jar: io/fabric8/openshift/api/model/console/v1/ConsoleCLIDownloadSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.console.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ConsoleCLIDownloadSpecFluentImpl<A extends ConsoleCLIDownloadSpecFluent<A>> extends BaseFluent<A> implements ConsoleCLIDownloadSpecFluent<A>{
  public ConsoleCLIDownloadSpecFluentImpl() {
  }
  public ConsoleCLIDownloadSpecFluentImpl(ConsoleCLIDownloadSpec instance) {
    this.withDescription(instance.getDescription()); 
    this.withDisplayName(instance.getDisplayName()); 
    this.withLinks(instance.getLinks()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String description;
  private String displayName;
  private ArrayList<CLIDownloadLinkBuilder> links = new ArrayList<CLIDownloadLinkBuilder>();
  private Map<String,Object> additionalProperties;
  public String getDescription() {
    return this.description;
  }
  public A withDescription(String description) {
    this.description=description; return (A) this;
  }
  public Boolean hasDescription() {
    return this.description != null;
  }
  public String getDisplayName() {
    return this.displayName;
  }
  public A withDisplayName(String displayName) {
    this.displayName=displayName; return (A) this;
  }
  public Boolean hasDisplayName() {
    return this.displayName != null;
  }
  public A addToLinks(Integer index,CLIDownloadLink item) {
    if (this.links == null) {this.links = new ArrayList<CLIDownloadLinkBuilder>();}
    CLIDownloadLinkBuilder builder = new CLIDownloadLinkBuilder(item);_visitables.get("links").add(index >= 0 ? index : _visitables.get("links").size(), builder);this.links.add(index >= 0 ? index : links.size(), builder); return (A)this;
  }
  public A setToLinks(Integer index,CLIDownloadLink item) {
    if (this.links == null) {this.links = new ArrayList<CLIDownloadLinkBuilder>();}
    CLIDownloadLinkBuilder builder = new CLIDownloadLinkBuilder(item);
    if (index < 0 || index >= _visitables.get("links").size()) { _visitables.get("links").add(builder); } else { _visitables.get("links").set(index, builder);}
    if (index < 0 || index >= links.size()) { links.add(builder); } else { links.set(index, builder);}
     return (A)this;
  }
  public A addToLinks(io.fabric8.openshift.api.model.console.v1.CLIDownloadLink... items) {
    if (this.links == null) {this.links = new ArrayList<CLIDownloadLinkBuilder>();}
    for (CLIDownloadLink item : items) {CLIDownloadLinkBuilder builder = new CLIDownloadLinkBuilder(item);_visitables.get("links").add(builder);this.links.add(builder);} return (A)this;
  }
  public A addAllToLinks(Collection<CLIDownloadLink> items) {
    if (this.links == null) {this.links = new ArrayList<CLIDownloadLinkBuilder>();}
    for (CLIDownloadLink item : items) {CLIDownloadLinkBuilder builder = new CLIDownloadLinkBuilder(item);_visitables.get("links").add(builder);this.links.add(builder);} return (A)this;
  }
  public A removeFromLinks(io.fabric8.openshift.api.model.console.v1.CLIDownloadLink... items) {
    for (CLIDownloadLink item : items) {CLIDownloadLinkBuilder builder = new CLIDownloadLinkBuilder(item);_visitables.get("links").remove(builder);if (this.links != null) {this.links.remove(builder);}} return (A)this;
  }
  public A removeAllFromLinks(Collection<CLIDownloadLink> items) {
    for (CLIDownloadLink item : items) {CLIDownloadLinkBuilder builder = new CLIDownloadLinkBuilder(item);_visitables.get("links").remove(builder);if (this.links != null) {this.links.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromLinks(Predicate<CLIDownloadLinkBuilder> predicate) {
    if (links == null) return (A) this;
    final Iterator<CLIDownloadLinkBuilder> each = links.iterator();
    final List visitables = _visitables.get("links");
    while (each.hasNext()) {
      CLIDownloadLinkBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildLinks instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<CLIDownloadLink> getLinks() {
    return links != null ? build(links) : null;
  }
  public List<CLIDownloadLink> buildLinks() {
    return links != null ? build(links) : null;
  }
  public CLIDownloadLink buildLink(Integer index) {
    return this.links.get(index).build();
  }
  public CLIDownloadLink buildFirstLink() {
    return this.links.get(0).build();
  }
  public CLIDownloadLink buildLastLink() {
    return this.links.get(links.size() - 1).build();
  }
  public CLIDownloadLink buildMatchingLink(Predicate<CLIDownloadLinkBuilder> predicate) {
    for (CLIDownloadLinkBuilder item: links) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public Boolean hasMatchingLink(Predicate<CLIDownloadLinkBuilder> predicate) {
    for (CLIDownloadLinkBuilder item: links) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withLinks(List<CLIDownloadLink> links) {
    if (this.links != null) { _visitables.get("links").removeAll(this.links);}
    if (links != null) {this.links = new ArrayList(); for (CLIDownloadLink item : links){this.addToLinks(item);}} else { this.links = null;} return (A) this;
  }
  public A withLinks(io.fabric8.openshift.api.model.console.v1.CLIDownloadLink... links) {
    if (this.links != null) {this.links.clear();}
    if (links != null) {for (CLIDownloadLink item :links){ this.addToLinks(item);}} return (A) this;
  }
  public Boolean hasLinks() {
    return links != null && !links.isEmpty();
  }
  public A addNewLink(String href,String text) {
    return (A)addToLinks(new CLIDownloadLink(href, text));
  }
  public ConsoleCLIDownloadSpecFluent.LinksNested<A> addNewLink() {
    return new ConsoleCLIDownloadSpecFluentImpl.LinksNestedImpl();
  }
  public ConsoleCLIDownloadSpecFluent.LinksNested<A> addNewLinkLike(CLIDownloadLink item) {
    return new ConsoleCLIDownloadSpecFluentImpl.LinksNestedImpl(-1, item);
  }
  public ConsoleCLIDownloadSpecFluent.LinksNested<A> setNewLinkLike(Integer index,CLIDownloadLink item) {
    return new ConsoleCLIDownloadSpecFluentImpl.LinksNestedImpl(index, item);
  }
  public ConsoleCLIDownloadSpecFluent.LinksNested<A> editLink(Integer index) {
    if (links.size() <= index) throw new RuntimeException("Can't edit links. Index exceeds size.");
    return setNewLinkLike(index, buildLink(index));
  }
  public ConsoleCLIDownloadSpecFluent.LinksNested<A> editFirstLink() {
    if (links.size() == 0) throw new RuntimeException("Can't edit first links. The list is empty.");
    return setNewLinkLike(0, buildLink(0));
  }
  public ConsoleCLIDownloadSpecFluent.LinksNested<A> editLastLink() {
    int index = links.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last links. The list is empty.");
    return setNewLinkLike(index, buildLink(index));
  }
  public ConsoleCLIDownloadSpecFluent.LinksNested<A> editMatchingLink(Predicate<CLIDownloadLinkBuilder> predicate) {
    int index = -1;
    for (int i=0;i<links.size();i++) { 
    if (predicate.test(links.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching links. No match found.");
    return setNewLinkLike(index, buildLink(index));
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ConsoleCLIDownloadSpecFluentImpl that = (ConsoleCLIDownloadSpecFluentImpl) o;
    if (description != null ? !description.equals(that.description) :that.description != null) return false;
    if (displayName != null ? !displayName.equals(that.displayName) :that.displayName != null) return false;
    if (links != null ? !links.equals(that.links) :that.links != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(description,  displayName,  links,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (description != null) { sb.append("description:"); sb.append(description + ","); }
    if (displayName != null) { sb.append("displayName:"); sb.append(displayName + ","); }
    if (links != null && !links.isEmpty()) { sb.append("links:"); sb.append(links + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class LinksNestedImpl<N> extends CLIDownloadLinkFluentImpl<ConsoleCLIDownloadSpecFluent.LinksNested<N>> implements ConsoleCLIDownloadSpecFluent.LinksNested<N>,Nested<N>{
    LinksNestedImpl(Integer index,CLIDownloadLink item) {
      this.index = index;
      this.builder = new CLIDownloadLinkBuilder(this, item);
    }
    LinksNestedImpl() {
      this.index = -1;
      this.builder = new CLIDownloadLinkBuilder(this);
    }
    CLIDownloadLinkBuilder builder;
    Integer index;
    public N and() {
      return (N) ConsoleCLIDownloadSpecFluentImpl.this.setToLinks(index,builder.build());
    }
    public N endLink() {
      return and();
    }
    
  }
  
}

==> openshift-model-console-6.7.2-sources.jar: io/fabric8/openshift/api/model/console/v1/ConsoleCLIDownloadSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.console.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ConsoleCLIDownloadSpecFluentImpl<A extends ConsoleCLIDownloadSpecFluent<A>> extends BaseFluent<A> implements ConsoleCLIDownloadSpecFluent<A>{
  public ConsoleCLIDownloadSpecFluentImpl() {
  }
  public ConsoleCLIDownloadSpecFluentImpl(ConsoleCLIDownloadSpec instance) {
    if (instance != null) {
      this.withDescription(instance.getDescription());
      this.withDisplayName(instance.getDisplayName());
      this.withLinks(instance.getLinks());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String description;
  private String displayName;
  private ArrayList<CLIDownloadLinkBuilder> links = new ArrayList<CLIDownloadLinkBuilder>();
  private Map<String,Object> additionalProperties;
  public String getDescription() {
    return this.description;
  }
  public A withDescription(String description) {
    this.description=description; return (A) this;
  }
  public Boolean hasDescription() {
    return this.description != null;
  }
  public String getDisplayName() {
    return this.displayName;
  }
  public A withDisplayName(String displayName) {
    this.displayName=displayName; return (A) this;
  }
  public Boolean hasDisplayName() {
    return this.displayName != null;
  }
  public A addToLinks(int index,CLIDownloadLink item) {
    if (this.links == null) {this.links = new ArrayList<CLIDownloadLinkBuilder>();}
    CLIDownloadLinkBuilder builder = new CLIDownloadLinkBuilder(item);
    if (index < 0 || index >= links.size()) { _visitables.get("links").add(builder); links.add(builder); } else { _visitables.get("links").add(index, builder); links.add(index, builder);}
    return (A)this;
  }
  public A setToLinks(int index,CLIDownloadLink item) {
    if (this.links == null) {this.links = new ArrayList<CLIDownloadLinkBuilder>();}
    CLIDownloadLinkBuilder builder = new CLIDownloadLinkBuilder(item);
    if (index < 0 || index >= links.size()) { _visitables.get("links").add(builder); links.add(builder); } else { _visitables.get("links").set(index, builder); links.set(index, builder);}
    return (A)this;
  }
  public A addToLinks(io.fabric8.openshift.api.model.console.v1.CLIDownloadLink... items) {
    if (this.links == null) {this.links = new ArrayList<CLIDownloadLinkBuilder>();}
    for (CLIDownloadLink item : items) {CLIDownloadLinkBuilder builder = new CLIDownloadLinkBuilder(item);_visitables.get("links").add(builder);this.links.add(builder);} return (A)this;
  }
  public A addAllToLinks(Collection<CLIDownloadLink> items) {
    if (this.links == null) {this.links = new ArrayList<CLIDownloadLinkBuilder>();}
    for (CLIDownloadLink item : items) {CLIDownloadLinkBuilder builder = new CLIDownloadLinkBuilder(item);_visitables.get("links").add(builder);this.links.add(builder);} return (A)this;
  }
  public A removeFromLinks(io.fabric8.openshift.api.model.console.v1.CLIDownloadLink... items) {
    for (CLIDownloadLink item : items) {CLIDownloadLinkBuilder builder = new CLIDownloadLinkBuilder(item);_visitables.get("links").remove(builder);if (this.links != null) {this.links.remove(builder);}} return (A)this;
  }
  public A removeAllFromLinks(Collection<CLIDownloadLink> items) {
    for (CLIDownloadLink item : items) {CLIDownloadLinkBuilder builder = new CLIDownloadLinkBuilder(item);_visitables.get("links").remove(builder);if (this.links != null) {this.links.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromLinks(Predicate<CLIDownloadLinkBuilder> predicate) {
    if (links == null) return (A) this;
    final Iterator<CLIDownloadLinkBuilder> each = links.iterator();
    final List visitables = _visitables.get("links");
    while (each.hasNext()) {
      CLIDownloadLinkBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildLinks instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<CLIDownloadLink> getLinks() {
    return links != null ? build(links) : null;
  }
  public List<CLIDownloadLink> buildLinks() {
    return links != null ? build(links) : null;
  }
  public CLIDownloadLink buildLink(int index) {
    return this.links.get(index).build();
  }
  public CLIDownloadLink buildFirstLink() {
    return this.links.get(0).build();
  }
  public CLIDownloadLink buildLastLink() {
    return this.links.get(links.size() - 1).build();
  }
  public CLIDownloadLink buildMatchingLink(Predicate<CLIDownloadLinkBuilder> predicate) {
    for (CLIDownloadLinkBuilder item: links) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public Boolean hasMatchingLink(Predicate<CLIDownloadLinkBuilder> predicate) {
    for (CLIDownloadLinkBuilder item: links) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withLinks(List<CLIDownloadLink> links) {
    if (this.links != null) { _visitables.get("links").clear();}
    if (links != null) {this.links = new ArrayList(); for (CLIDownloadLink item : links){this.addToLinks(item);}} else { this.links = null;} return (A) this;
  }
  public A withLinks(io.fabric8.openshift.api.model.console.v1.CLIDownloadLink... links) {
    if (this.links != null) {this.links.clear(); _visitables.remove("links"); }
    if (links != null) {for (CLIDownloadLink item :links){ this.addToLinks(item);}} return (A) this;
  }
  public Boolean hasLinks() {
    return links != null && !links.isEmpty();
  }
  public A addNewLink(String href,String text) {
    return (A)addToLinks(new CLIDownloadLink(href, text));
  }
  public ConsoleCLIDownloadSpecFluentImpl.LinksNested<A> addNewLink() {
    return new ConsoleCLIDownloadSpecFluentImpl.LinksNestedImpl();
  }
  public ConsoleCLIDownloadSpecFluentImpl.LinksNested<A> addNewLinkLike(CLIDownloadLink item) {
    return new ConsoleCLIDownloadSpecFluentImpl.LinksNestedImpl(-1, item);
  }
  public ConsoleCLIDownloadSpecFluentImpl.LinksNested<A> setNewLinkLike(int index,CLIDownloadLink item) {
    return new ConsoleCLIDownloadSpecFluentImpl.LinksNestedImpl(index, item);
  }
  public ConsoleCLIDownloadSpecFluentImpl.LinksNested<A> editLink(int index) {
    if (links.size() <= index) throw new RuntimeException("Can't edit links. Index exceeds size.");
    return setNewLinkLike(index, buildLink(index));
  }
  public ConsoleCLIDownloadSpecFluentImpl.LinksNested<A> editFirstLink() {
    if (links.size() == 0) throw new RuntimeException("Can't edit first links. The list is empty.");
    return setNewLinkLike(0, buildLink(0));
  }
  public ConsoleCLIDownloadSpecFluentImpl.LinksNested<A> editLastLink() {
    int index = links.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last links. The list is empty.");
    return setNewLinkLike(index, buildLink(index));
  }
  public ConsoleCLIDownloadSpecFluentImpl.LinksNested<A> editMatchingLink(Predicate<CLIDownloadLinkBuilder> predicate) {
    int index = -1;
    for (int i=0;i<links.size();i++) { 
    if (predicate.test(links.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching links. No match found.");
    return setNewLinkLike(index, buildLink(index));
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ConsoleCLIDownloadSpecFluentImpl that = (ConsoleCLIDownloadSpecFluentImpl) o;
    if (!java.util.Objects.equals(description, that.description)) return false;

    if (!java.util.Objects.equals(displayName, that.displayName)) return false;

    if (!java.util.Objects.equals(links, that.links)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(description,  displayName,  links,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (description != null) { sb.append("description:"); sb.append(description + ","); }
    if (displayName != null) { sb.append("displayName:"); sb.append(displayName + ","); }
    if (links != null) { sb.append("links:"); sb.append(links + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class LinksNestedImpl<N> extends CLIDownloadLinkFluentImpl<ConsoleCLIDownloadSpecFluentImpl.LinksNested<N>> implements ConsoleCLIDownloadSpecFluentImpl.LinksNested<N>,Nested<N>{
    LinksNestedImpl(int index,CLIDownloadLink item) {
      this.index = index;
      this.builder = new CLIDownloadLinkBuilder(this, item);
    }
    LinksNestedImpl() {
      this.index = -1;
      this.builder = new CLIDownloadLinkBuilder(this);
    }
    CLIDownloadLinkBuilder builder;
    int index;
    public N and() {
      return (N) ConsoleCLIDownloadSpecFluentImpl.this.setToLinks(index,builder.build());
    }
    public N endLink() {
      return and();
    }
    
  }
  
}
